==> haskell-vty-5.21-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vty
version: 5.21
id: vty-5.21-JGeq0jO2kQnJLYTvADkkak
key: vty-5.21-JGeq0jO2kQnJLYTvADkkak
license: BSD-3-Clause
maintainer: Jonathan Daugherty (cygnus@foobox.com)
author: AUTHORS
homepage: https://github.com/jtdaugherty/vty
synopsis: A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.
    .
    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.
    .
    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.
    .
    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.
    .
    &#169; Corey O'\''Connor; BSD3 license.
    .
    &#169; Jonathan Daugherty; BSD3 license.
category: User Interfaces
abi: dbde7d31eadb3113149e42597ee38795
exposed: True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
hidden-modules: Graphics.Vty.Attributes.Color
                Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
                Graphics.Vty.Input.Terminfo.ANSIVT
import-dirs: /usr/lib/ghc-8.4.2/site-local/vty-5.21
library-dirs: /usr/lib/ghc-8.4.2/site-local/vty-5.21
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/vty-5.21
hs-libraries: HSvty-5.21-JGeq0jO2kQnJLYTvADkkak
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    bytestring-0.10.8.2 containers-0.5.11.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh
    microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5
    microlens-th-0.4.2.1-8kcGgDkORR13vi5AtN2HGZ
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg mtl-2.2.2
    parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE parsec-3.1.13.0 stm-2.4.5.0
    terminfo-0.4.1.1 transformers-0.5.5.0 text-1.2.3.0 unix-2.7.2.2
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=a6b0b26ea14b9a093ef6d86c6b4d483f
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh=fcc5d41c500c3c3fe4b61569dcef1191
             microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5=c72a38208bedb4e0e74eaecdaea9b3ce
             microlens-th-0.4.2.1-8kcGgDkORR13vi5AtN2HGZ=de9986f07e92b074c4215996a7db1461
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0e3ad496fde59157bcd6a630b4b29548
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE=5acc896b5484fd32116fb868fccee170
             parsec-3.1.13.0=b976f306e11b572c7d5898bcff511199
             stm-2.4.5.0=fc4e40e3aa6203460dfa01934bcd44f0
             terminfo-0.4.1.1=e4d7cad747ffec3ab5f5fabaebde7a04
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             unix-2.7.2.2=52cd75b8c492339f1bc16a6e08d9b9d7
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=98c3aed4d9f965690ee596928a6a8eec
             vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb=6eab66b6328cb1f1f60a88d42282d4d0
haddock-interfaces: /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html: /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-5.21-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vty
version: 5.21
id: vty-5.21-HRPmDh9Yb1UT8R6S5GPaF
key: vty-5.21-HRPmDh9Yb1UT8R6S5GPaF
license: BSD-3-Clause
maintainer: Jonathan Daugherty (cygnus@foobox.com)
author: AUTHORS
homepage: https://github.com/jtdaugherty/vty
synopsis: A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.
    .
    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.
    .
    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.
    .
    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.
    .
    &#169; Corey O'\''Connor; BSD3 license.
    .
    &#169; Jonathan Daugherty; BSD3 license.
category: User Interfaces
abi: c571c467541fdb019ba12e2c85bad78d
exposed: True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
hidden-modules: Graphics.Vty.Attributes.Color
                Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
                Graphics.Vty.Input.Terminfo.ANSIVT
import-dirs: /usr/lib/ghc-8.4.3/site-local/vty-5.21
library-dirs: /usr/lib/ghc-8.4.3/site-local/vty-5.21
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/vty-5.21
hs-libraries: HSvty-5.21-HRPmDh9Yb1UT8R6S5GPaF
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    bytestring-0.10.8.2 containers-0.5.11.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh
    microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5
    microlens-th-0.4.2.1-8kcGgDkORR13vi5AtN2HGZ
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg mtl-2.2.2
    parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE parsec-3.1.13.0 stm-2.4.5.0
    terminfo-0.4.1.1 transformers-0.5.5.0 text-1.2.3.0 unix-2.7.2.2
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh=c8c360537bf1a4bd1c492e28d6784d61
             microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5=7dca9a0e1e04d414a3f7d4a897abe463
             microlens-th-0.4.2.1-8kcGgDkORR13vi5AtN2HGZ=2ca7be4f5ca83b04ac7e3779ef211e11
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE=b5c7268b9b5d05fd127858174b9c4c3a
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             terminfo-0.4.1.1=80248163b7e42caee42f65390beab7f1
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html: /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
